import createPlayerDB from "./createPlayerDB"
import createTokenDB, { RawToken } from "./createTokenDB"
import type { API } from "./sendError"
import { setCookie } from "cookies-next"

async function getTokenFromCookie<T>(
  context: API<T>,
  next: (refreshToken: RawToken) => void
) {
  const type = "REFRESH"
  const { req, res } = context
  const value = req.cookies.token

  // Checking for cookie presens, because it is necessary
  if (!value) {
    return createPlayerDB((player) =>
      createTokenDB(player, type, (newToken) => {
        // Set login cookie
        setCookie("token", newToken.value, {
          req,
          res,
          maxAge: 172800,
          httpOnly: true,
          sameSite: true,
          secure: true,
          path: "/api",
        })
        return next(newToken)
      })
    )
  }
  return next({ value, type })
}

export default getTokenFromCookie
