import sendError from "@backend/components/sendError"
import sendResponse from "@backend/components/sendResponse"
import getPinFromBody from "@lib/backend/components/getPinFromBody"
import getPlayer from "@lib/backend/components/getPlayer"
import prisma from "@lib/prisma"
import type { Game } from "@prisma/client"
import type { NextApiRequest, NextApiResponse } from "next"

interface Data {
  game: Game
}

export default async function join(
  req: NextApiRequest,
  res: NextApiResponse<Data>
) {
  const context = { req, res }

  return getPinFromBody(context, (pin) =>
    getPlayer(context, async (player) => {
      const { game } = await prisma.gamepin.update({
        where: {
          pin,
        },
        data: {
          game: {
            update: {
              players: {
                create: {
                  isOwner: false,
                  playerId: player.id,
                },
              },
            },
          },
        },
        include: { game: true },
      })

      sendResponse(context, {
        message: `Player: ${player.id} joined game: ${game.id}`,
        body: { game },
        type: ["debug", "infoCyan"],
      })
    })
  ).catch((err) => sendError(context, err))
}
