import checkTokenIsValid from "@backend/components/checkTokenIsValid"
import getPlayerByIdDB from "@backend/components/getPlayerByIdDB"
import getTokenDB from "@backend/components/getTokenDB"
import getTokenFromCookie from "@backend/components/getTokenFromCookie"
import sendError from "@backend/components/sendError"
import sendResponse from "@backend/components/sendResponse"
import type { NextApiRequest, NextApiResponse } from "next"

interface Data {
  token: string
}

export default async function auth(
  req: NextApiRequest,
  res: NextApiResponse<Data>
) {
  const context = { req, res }

  getTokenFromCookie(context, (refreshToken) => {
    checkTokenIsValid(context, refreshToken, (token) => {
      getTokenDB(context, token, (tokenDB) => {
        getPlayerByIdDB(context, tokenDB, (player) => {
          sendResponse(context, {
            message: "loginCheck -> true : " + player.id,
            type: ["debug", "infoCyan"],
          })
        })
      })
    })
  }).catch((err) => sendError(context, err))
}
