import getTokenDB from "@backend/components/getTokenDB"
import getTokenFromCookie from "@backend/components/getTokenFromCookie"
import sendError from "@backend/components/sendError"
import sendResponse from "@backend/components/sendResponse"
import decodeToken from "@lib/backend/components/decodeToken"
import { deleteCookie } from "cookies-next"
import type { NextApiRequest, NextApiResponse } from "next"

interface Data {
  loggedOut: boolean
}

export default async function logout(
  req: NextApiRequest,
  res: NextApiResponse<any>
) {
  const context = { req, res }

  return getTokenFromCookie(context, (refreshToken) =>
    decodeToken(context, refreshToken, (token) =>
      getTokenDB(
        context,
        token,
        (tokenDB) => {
          // Set login cookie
          deleteCookie("token", { req, res })

          return sendResponse(context, {
            message: "User of Token " + tokenDB.id + " logged out.",
            body: { loggedOut: true },
            type: ["debug", "infoCyan"],
          })
        },
        true
      )
    )
  ).catch((err) => sendError(context, err))
}
