import BurgerMenu from "../../components/BurgerMenu"
import Logo from "../../components/Logo"
import OptionButton from "../../components/OptionButton"
import { faEye, faLeftLong } from "@fortawesome/pro-regular-svg-icons"
import { faPlus, faUserPlus } from "@fortawesome/pro-solid-svg-icons"
import { faCirclePlay } from "@fortawesome/pro-thin-svg-icons"
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome"
import getAccessToken from "@lib/frontend/getAccessToken"
import { GetServerSideProps } from "next"
import { useRouter } from "next/router"
import { useState } from "react"
import { z } from "zod"

interface Props {
  start: boolean
}

export default function Home({ start }: Props) {
  const router = useRouter()
  return (
    <div className="h-full bg-theme">
      <div className="mx-auto flex h-full max-w-screen-md flex-col items-center justify-evenly">
        <Logo />
        <BurgerMenu />
        {!start ? (
          <>
            <div className="flex h-36 w-64 items-center justify-center rounded-xl border-4 border-black bg-[#2227] sm:h-48 sm:w-96 md:h-72 md:w-[32rem] md:border-[6px] xl:h-[26rem] xl:w-[48rem]">
              <FontAwesomeIcon
                className="text-6xl sm:text-7xl md:text-8xl"
                icon={faCirclePlay}
              />
            </div>
            <button
              className="font-farro rounded-lg border-b-4 border-orange-400 bg-warn px-12 pb-4 pt-5 text-2xl font-bold duration-100 active:border-b-0 active:border-t-4 sm:rounded-xl sm:border-b-[6px] sm:px-14 sm:pb-5 sm:pt-6 sm:text-3xl sm:active:border-t-[6px] md:rounded-2xl md:border-b-8 md:px-20 md:pb-6 md:pt-7 md:text-4xl md:active:border-t-8 xl:px-24 xl:pb-8 xl:pt-10 xl:text-5xl"
              onClick={() =>
                setTimeout(() => {
                  // Navigate to the same page with the `start` query parameter set to `true`
                  router.push({
                    pathname: router.pathname,
                    query: { start: true },
                  })
                }, 200)
              }
            >
              START
            </button>
          </>
        ) : (
          <div className="flex flex-col items-center rounded-xl border-4 border-black bg-grayish px-4 py-6 shadow-lg sm:mx-8 sm:p-12 md:w-full">
            <button
              className="-mt-2 w-20 self-start rounded-xl border-b-4 border-shield-gray bg-voidDark text-2xl text-grayish duration-100 active:border-b-0 active:border-t-4 sm:-mt-6 sm:w-40 sm:px-2 sm:text-5xl"
              onClick={() =>
                setTimeout(() => {
                  // Navigate to the same page with the `start` query parameter set to `false`
                  router.push({
                    pathname: router.pathname,
                  })
                }, 200)
              }
            >
              <FontAwesomeIcon icon={faLeftLong} />
            </button>
            <div className="flex flex-col items-center gap-6 sm:gap-12">
              <OptionButton
                action={async () => {
                  const token = await getAccessToken()
                  const game = await fetch("/api/game/create", {
                    method: "POST",
                    body: JSON.stringify({ token }),
                  })
                  const gameSchema = z.object({
                    game: z.object({
                      id: z.string(),
                      createdAt: z.date(),
                      updatedAt: z.date(),
                      running: z.boolean(),
                    }),
                  })

                  const check = gameSchema.safeParse(game)

                  if (check.success) {
                    const gameData = check.data
                    console.log(gameData)
                  } else {
                    console.error(check.error)
                  }

                  // const warst = result.game

                  router.push("/dev/lobby")
                }}
                icon={faPlus}
              >
                Raum erstellen
              </OptionButton>
              <OptionButton icon={faUserPlus}>Raum beitreten</OptionButton>
              <OptionButton icon={faEye}>Zuschauen</OptionButton>
            </div>
          </div>
        )}
      </div>
    </div>
  )
}

export const getServerSideProps: GetServerSideProps<Props> = async (
  context
) => {
  const { start } = context.query

  // Convert the `start` query parameter to a boolean
  const isStart = start === "true"

  return { props: { start: isStart } }
}
